### Project description

Faclon Weather Data Access Library

#### Where to get it

https://pypi.org/project/iosense/

#### Installation

pip install weather-connect

pip3 install weather-connect

#### Features

Retrives following details:

- Plant information.
- Weather Details.p

#### Dependencies

+ pandas
+ requests
+ json
+ pymongo

#### Documentation

The official documentation is hosted on

#### Reach us

For usage questions, please reach out to us at reachus@faclon.com
